@@ -1,5 +1,5 @@
 package OPM::Maker::Command::build;
-$OPM::Maker::Command::build::VERSION = '1.10';
+$OPM::Maker::Command::build::VERSION = '1.11';
 use strict;
 use warnings;
 
@@ -12,7 +12,7 @@ use Path::Class ();
 use XML::LibXML;
 
 use OPM::Maker -command;
-use OPM::Maker::Utils qw(reformat_size);
+use OPM::Maker::Utils qw(reformat_size check_args_sopm);
 
 sub abstract {
     return "build package files for Znuny, OTOBO or ((OTRS)) Community Edition";
@@ -32,18 +32,16 @@ sub opt_spec {
 sub validate_args {
     my ($self, $opt, $args) = @_;
 
+    my $sopm = check_args_sopm( $args );
+
     $self->usage_error( 'need path to .sopm' ) if
-        !$args or 
-        'ARRAY' ne ref $args or
-        !defined $args->[0] or
-        $args->[0] !~ /\.sopm\z/ or
-        !-f $args->[0];
+        !$sopm;
 }
 
 sub execute {
     my ($self, $opt, $args) = @_;
 
-    my $file = $args->[0];
+    my $file = check_args_sopm( $args );
 
     my $hostname  = hostname;
     my @time      = localtime;
@@ -138,7 +136,7 @@ OPM::Maker::Command::build - Build OPM packages
 
 =head1 VERSION
 
-version 1.10
+version 1.11
 
 =head1 AUTHOR
 
