@@ -1,5 +1,5 @@
 package OPM::Maker::Command::dbtest;
-$OPM::Maker::Command::dbtest::VERSION = '1.10';
+$OPM::Maker::Command::dbtest::VERSION = '1.11';
 # ABSTRACT: Test db definitions in .sopm files
 
 use strict;
@@ -7,6 +7,8 @@ use warnings;
 
 use OPM::Maker -command;
 
+use OPM::Maker::Utils qw(check_args_sopm);
+
 sub abstract {
     return "Check if DatabaseInstall and DatabaseUninstall sections in the .sopm are correct";
 }
@@ -18,16 +20,16 @@ sub usage_desc {
 sub validate_args {
     my ($self, $opt, $args) = @_;
 
+    my $sopm = check_args_sopm( $args );
+
     $self->usage_error( 'need path to .sopm' ) if
-        !$args or
-        'ARRAY' ne ref $args or
-        !defined $args->[0] or
-        $args->[0] !~ /\.sopm\z/ or
-        !-f $args->[0];
+        !$sopm;
 }
 
 sub execute {
     my ($self, $opt, $args) = @_;
+
+    die "not implemented yet";
 }
 
 1;
@@ -44,7 +46,7 @@ OPM::Maker::Command::dbtest - Test db definitions in .sopm files
 
 =head1 VERSION
 
-version 1.10
+version 1.11
 
 =head1 AUTHOR
 
