@@ -1,5 +1,5 @@
 package OPM::Maker::Command::dependencies;
-$OPM::Maker::Command::dependencies::VERSION = '1.10';
+$OPM::Maker::Command::dependencies::VERSION = '1.11';
 # ABSTRACT: List dependencies of OTRS packages
 
 use strict;
@@ -9,7 +9,7 @@ use Carp qw(croak);
 use XML::LibXML;
 
 use OPM::Maker -command;
-use OPM::Maker::Utils qw(reformat_size);
+use OPM::Maker::Utils qw(reformat_size check_args_sopm);
 
 sub abstract {
     return "list dependencies for OPM packages";
@@ -21,19 +21,16 @@ sub usage_desc {
 
 sub validate_args {
     my ($self, $opt, $args) = @_;
-    
+
+    my $sopm = check_args_sopm( $args, 1 );
     $self->usage_error( 'need path to .sopm or .opm' ) if
-        !$args or
-        'ARRAY' ne ref $args or
-        !defined $args->[0] or
-        $args->[0] !~ /\.s?opm\z/ or
-        !-f $args->[0];
+        !$sopm;
 }
 
 sub execute {
     my ($self, $opt, $args) = @_;
     
-    my $file = $args->[0];
+    my $file = check_args_sopm( $args, 1 );
 
     my %opts;
     if ( !$ENV{OPM_UNSECURE} ) {
@@ -97,7 +94,7 @@ OPM::Maker::Command::dependencies - List dependencies of OTRS packages
 
 =head1 VERSION
 
-version 1.10
+version 1.11
 
 =head1 AUTHOR
 
