@@ -1,5 +1,5 @@
 package OPM::Maker::Command::filetest;
-$OPM::Maker::Command::filetest::VERSION = '1.10';
+$OPM::Maker::Command::filetest::VERSION = '1.11';
 # ABSTRACT: check if filelist in .sopm includes the files on your disk
 
 use strict;
@@ -8,10 +8,14 @@ use warnings;
 use Carp qw(croak);
 use File::Find::Rule;
 use Path::Class ();
+use Text::Gitignore qw(match_gitignore);
 use XML::LibXML;
 
 use OPM::Maker -command;
-use OPM::Maker::Utils qw(reformat_size);
+use OPM::Maker::Utils qw(
+    reformat_size
+    check_args_sopm
+);
 
 sub abstract {
     return "Check if filelist in .sopm includes the files on your disk";
@@ -23,19 +27,17 @@ sub usage_desc {
 
 sub validate_args {
     my ($self, $opt, $args) = @_;
+
+    my $sopm = check_args_sopm( $args );
     
     $self->usage_error( 'need path to .sopm' ) if
-        !$args or
-        'ARRAY' ne ref $args or
-        !defined $args->[0] or
-        $args->[0] !~ /\.sopm\z/ or
-        !-f $args->[0];
+        !$sopm;
 }
 
 sub execute {
     my ($self, $opt, $args) = @_;
 
-    my $file = $args->[0];
+    my $file = check_args_sopm( $args );
 
     my %opts;
     if ( !$ENV{OPM_UNSECURE} ) {
@@ -68,35 +70,59 @@ sub execute {
     my $path      = $sopm_path->dir;
     
     my $path_str     = $path->stringify;
-    my $ignore_files = File::Find::Rule->file->name(".*");    
+    my $hidden_files = File::Find::Rule->file->name(".*");
     my @files_in_fs  = File::Find::Rule->file
-        ->not( $ignore_files )
+        ->not( $hidden_files )
         ->in ( $path_str );
     
     my %fs = map{ $_ =~ s{\A\Q$path_str\E/?}{}; $_ => 1 }
         grep{ $_ !~ /\.git|CVS|svn/ }@files_in_fs;
         
     delete $fs{ $sopm_path->basename };
-    
+
+    my $ignore_file = Path::Class::File->new(
+        $path->stringify,
+        '.opmbuild_filetest_ignore',
+    );
+
     my $root_elem = $tree->getDocumentElement;
     
     # retrieve file information
     my @files = $root_elem->findnodes( 'Filelist/File' );
-    
+
     my @not_found;
-    
+
     FILE:
     for my $file ( @files ) {
         my $name = $file->findvalue( '@Location' );
         
         push @not_found, $name if !delete $fs{$name};
     }
-    
+
     if ( @not_found ) {
         print "Files listed in .sopm but not found on disk:\n",
             map{ "    - $_\n" }@not_found;
     }
-    
+
+    my @patterns;
+    eval {
+        @patterns = $ignore_file->slurp(
+            chomp  => 1,
+            iomode => '<:encoding(utf-8)',
+        );
+    };
+
+    if ( @patterns ) {
+        my @ignore = match_gitignore(
+            [ @patterns ],
+            keys %fs,
+        );
+
+        if ( @ignore ) {
+            delete @fs{@ignore};
+        }
+    }
+
     if ( %fs ) {
         print "Files found on disk but not listed in .sopm:\n",
             map{ "    - $_\n" }sort keys %fs;
@@ -117,7 +143,7 @@ OPM::Maker::Command::filetest - check if filelist in .sopm includes the files on
 
 =head1 VERSION
 
-version 1.10
+version 1.11
 
 =head1 AUTHOR
 
