@@ -1,5 +1,5 @@
 package OPM::Maker::Command::sopmtest;
-$OPM::Maker::Command::sopmtest::VERSION = '1.10';
+$OPM::Maker::Command::sopmtest::VERSION = '1.11';
 # ABSTRACT: Check if sopm is valid
 
 use strict;
@@ -9,6 +9,7 @@ use Path::Class ();
 use OPM::Validate;
 
 use OPM::Maker -command;
+use OPM::Maker::Utils qw(check_args_sopm);
 
 sub abstract {
     return "check .sopm if it is valid";
@@ -20,19 +21,16 @@ sub usage_desc {
 
 sub validate_args {
     my ($self, $opt, $args) = @_;
-    
+
+    my $sopm = check_args_sopm( $args, 1 );
     $self->usage_error( 'need path to .sopm' ) if
-        !$args or
-        'ARRAY' ne ref $args or
-        !defined $args->[0] or
-        $args->[0] !~ /\.sopm\z/ or
-        !-f $args->[0];
+        !$sopm;
 }
 
 sub execute {
     my ($self, $opt, $args) = @_;
     
-    my $file = $args->[0];
+    my $file = check_args_sopm( $args, 1 );
 
     if ( !defined $file ) {
         print "No file given!";
@@ -70,7 +68,7 @@ OPM::Maker::Command::sopmtest - Check if sopm is valid
 
 =head1 VERSION
 
-version 1.10
+version 1.11
 
 =head1 AUTHOR
 
